
Soma-base documentation
=======================

Many miscellaneous all-purpose classes and functions...

License: `CeCILL-B <http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html>`_


Main module: ``soma.api``
+++++++++++++++++++++++++

.. automodule:: soma.api
  :members:


Sub-modules
+++++++++++

.. toctree::
    :maxdepth: 1

    api.rst
